@@ -10,24 +10,22 @@
 namespace SebastianBergmann\Type;
 
 use Closure;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\TestFixture\ClassWithCallbackMethods;
 use SebastianBergmann\Type\TestFixture\ClassWithInvokeMethod;
 
-/**
- * @covers \SebastianBergmann\Type\CallableType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\TypeName
- */
+#[CoversClass(CallableType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class CallableTypeTest extends TestCase
 {
-    /**
-     * @var CallableType
-     */
-    private $type;
+    private CallableType $type;
 
     protected function setUp(): void
     {
@@ -69,9 +67,9 @@ final class CallableTypeTest extends TestCase
             $this->type->isAssignable(
                 new ObjectType(
                     TypeName::fromQualifiedName(Closure::class),
-                    false
-                )
-            )
+                    false,
+                ),
+            ),
         );
     }
 
@@ -81,9 +79,9 @@ final class CallableTypeTest extends TestCase
             $this->type->isAssignable(
                 new ObjectType(
                     TypeName::fromQualifiedName(ClassWithInvokeMethod::class),
-                    false
-                )
-            )
+                    false,
+                ),
+            ),
         );
     }
 
@@ -91,8 +89,8 @@ final class CallableTypeTest extends TestCase
     {
         $this->assertTrue(
             $this->type->isAssignable(
-                Type::fromValue('SebastianBergmann\Type\TestFixture\callback_function', false)
-            )
+                Type::fromValue('SebastianBergmann\Type\TestFixture\callback_function', false),
+            ),
         );
     }
 
@@ -100,8 +98,8 @@ final class CallableTypeTest extends TestCase
     {
         $this->assertTrue(
             $this->type->isAssignable(
-                Type::fromValue(ClassWithCallbackMethods::class . '::staticCallback', false)
-            )
+                Type::fromValue(ClassWithCallbackMethods::class . '::staticCallback', false),
+            ),
         );
     }
 
@@ -109,8 +107,8 @@ final class CallableTypeTest extends TestCase
     {
         $this->assertTrue(
             $this->type->isAssignable(
-                Type::fromValue([ClassWithCallbackMethods::class, 'staticCallback'], false)
-            )
+                Type::fromValue([ClassWithCallbackMethods::class, 'staticCallback'], false),
+            ),
         );
     }
 
@@ -118,8 +116,8 @@ final class CallableTypeTest extends TestCase
     {
         $this->assertTrue(
             $this->type->isAssignable(
-                Type::fromValue([new ClassWithCallbackMethods, 'nonStaticCallback'], false)
-            )
+                Type::fromValue([new ClassWithCallbackMethods, 'nonStaticCallback'], false),
+            ),
         );
     }
 
@@ -127,8 +125,8 @@ final class CallableTypeTest extends TestCase
     {
         $this->assertFalse(
             $this->type->isAssignable(
-                Type::fromValue(null, false)
-            )
+                Type::fromValue(null, false),
+            ),
         );
     }
 
@@ -137,17 +135,20 @@ final class CallableTypeTest extends TestCase
         $this->assertFalse(
             $this->type->isAssignable(
                 Type::fromValue(
-                    new class {
+                    new class
+                    {
                     },
-                    false
-                )
-            )
+                    false,
+                ),
+            ),
         );
     }
 
     public function testCanBeQueriedForType(): void
     {
+        /** @phpstan-ignore method.alreadyNarrowedType */
         $this->assertTrue($this->type->isCallable());
+
         $this->assertFalse($this->type->isFalse());
         $this->assertFalse($this->type->isGenericObject());
         $this->assertFalse($this->type->isIntersection());
