@@ -9,23 +9,54 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use stdClass;
 
-/**
- * @covers \SebastianBergmann\Type\SimpleType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\FalseType
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\TrueType
- * @uses \SebastianBergmann\Type\Type
- * @uses \SebastianBergmann\Type\TypeName
- * @uses \SebastianBergmann\Type\UnknownType
- * @uses \SebastianBergmann\Type\VoidType
- */
+#[CoversClass(SimpleType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(TrueType::class)]
+#[UsesClass(FalseType::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(TypeName::class)]
+#[UsesClass(UnknownType::class)]
+#[UsesClass(VoidType::class)]
+#[Small]
 final class SimpleTypeTest extends TestCase
 {
+    /**
+     * @return non-empty-array<non-empty-string, array{0: Type, 1: Type}>
+     */
+    public static function assignablePairs(): array
+    {
+        return [
+            'nullable to not nullable'     => [new SimpleType('int', false), new SimpleType('int', true)],
+            'not nullable to nullable'     => [new SimpleType('int', true), new SimpleType('int', false)],
+            'nullable to nullable'         => [new SimpleType('int', true), new SimpleType('int', true)],
+            'not nullable to not nullable' => [new SimpleType('int', false), new SimpleType('int', false)],
+            'null to nullable'             => [new SimpleType('int', true), new NullType],
+            'true to bool'                 => [new SimpleType('bool', false), new TrueType],
+            'false to bool'                => [new SimpleType('bool', false), new FalseType],
+        ];
+    }
+
+    /**
+     * @return non-empty-array<non-empty-string, array{0: Type, 1: Type}>
+     */
+    public static function notAssignablePairs(): array
+    {
+        return [
+            'null to not nullable' => [new SimpleType('int', false), new NullType],
+            'int to boolean'       => [new SimpleType('boolean', false), new SimpleType('int', false)],
+            'object'               => [new SimpleType('boolean', false), new ObjectType(TypeName::fromQualifiedName(stdClass::class), true)],
+            'unknown type'         => [new SimpleType('boolean', false), new UnknownType],
+            'void'                 => [new SimpleType('boolean', false), new VoidType],
+        ];
+    }
+
     public function testCanBeBool(): void
     {
         $type = new SimpleType('bool', false);
@@ -103,69 +134,73 @@ final class SimpleTypeTest extends TestCase
         $this->assertFalse($type->allowsNull());
     }
 
-    /**
-     * @dataProvider assignablePairs
-     */
+    #[DataProvider('assignablePairs')]
     public function testIsAssignable(Type $assignTo, Type $assignedType): void
     {
         $this->assertTrue($assignTo->isAssignable($assignedType));
     }
 
-    public function assignablePairs(): array
-    {
-        return [
-            'nullable to not nullable'     => [new SimpleType('int', false), new SimpleType('int', true)],
-            'not nullable to nullable'     => [new SimpleType('int', true), new SimpleType('int', false)],
-            'nullable to nullable'         => [new SimpleType('int', true), new SimpleType('int', true)],
-            'not nullable to not nullable' => [new SimpleType('int', false), new SimpleType('int', false)],
-            'null to nullable'             => [new SimpleType('int', true), new NullType],
-            'true to bool'                 => [new SimpleType('bool', false), new TrueType],
-            'false to bool'                => [new SimpleType('bool', false), new FalseType],
-        ];
-    }
-
-    /**
-     * @dataProvider notAssignablePairs
-     */
+    #[DataProvider('notAssignablePairs')]
     public function testIsNotAssignable(Type $assignTo, Type $assignedType): void
     {
         $this->assertFalse($assignTo->isAssignable($assignedType));
     }
 
-    public function notAssignablePairs(): array
-    {
-        return [
-            'null to not nullable' => [new SimpleType('int', false), new NullType],
-            'int to boolean'       => [new SimpleType('boolean', false), new SimpleType('int', false)],
-            'object'               => [new SimpleType('boolean', false), new ObjectType(TypeName::fromQualifiedName(stdClass::class), true)],
-            'unknown type'         => [new SimpleType('boolean', false), new UnknownType],
-            'void'                 => [new SimpleType('boolean', false), new VoidType],
-        ];
-    }
-
     public function testCanHaveValue(): void
     {
-        $this->assertSame('string', Type::fromValue('string', false)->value());
+        $type = Type::fromValue('string', false);
+
+        $this->assertInstanceOf(SimpleType::class, $type);
+        $this->assertSame('string', $type->value());
     }
 
     public function testCanBeQueriedForType(): void
     {
         $type = new SimpleType('bool', false);
 
-        $this->assertFalse($type->isCallable());
-        $this->assertFalse($type->isFalse());
-        $this->assertFalse($type->isGenericObject());
-        $this->assertFalse($type->isIntersection());
-        $this->assertFalse($type->isIterable());
-        $this->assertFalse($type->isMixed());
-        $this->assertFalse($type->isNever());
-        $this->assertFalse($type->isNull());
-        $this->assertFalse($type->isObject());
+        /** @phpstan-ignore method.alreadyNarrowedType */
         $this->assertTrue($type->isSimple());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isCallable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isFalse());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isGenericObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIntersection());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIterable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isMixed());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNever());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNull());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isObject());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isStatic());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isTrue());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isUnion());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isUnknown());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isVoid());
     }
 
